@@ -17,15 +17,15 @@ Last updated: 1/5/2010
 *****************************************************/
 #include <stdlib.h>
 #include <stdio.h>
-#include <msa.h>
+#include <phast/msa.h>
 #include <getopt.h>
 #include <ctype.h>
-#include <sufficient_stats.h>
-#include <local_alignment.h>
-#include <gff.h>
-#include <misc.h>
-#include <list_of_lists.h>
-#include <rph_util.h>
+#include <phast/sufficient_stats.h>
+#include <phast/local_alignment.h>
+#include <phast/gff.h>
+#include <phast/misc.h>
+#include <phast/list_of_lists.h>
+#include <phast/rph_util.h>
 #include <limits.h>
 
 #include <Rdefines.h>
